# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Cloudsave Service."""

__version__ = "3.21.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# admin_concurrent_record
from .wrappers import admin_put_admin_game_record_concurrent_handler_v1
from .wrappers import admin_put_admin_game_record_concurrent_handler_v1_async
from .wrappers import admin_put_admin_player_record_concurrent_handler_v1
from .wrappers import admin_put_admin_player_record_concurrent_handler_v1_async
from .wrappers import admin_put_game_record_concurrent_handler_v1
from .wrappers import admin_put_game_record_concurrent_handler_v1_async
from .wrappers import admin_put_player_public_record_concurrent_handler_v1
from .wrappers import admin_put_player_public_record_concurrent_handler_v1_async
from .wrappers import admin_put_player_record_concurrent_handler_v1
from .wrappers import admin_put_player_record_concurrent_handler_v1_async

# admin_game_binary_record
from .wrappers import admin_delete_game_binary_record_v1
from .wrappers import admin_delete_game_binary_record_v1_async
from .wrappers import admin_get_game_binary_record_v1
from .wrappers import admin_get_game_binary_record_v1_async
from .wrappers import admin_list_game_binary_records_v1
from .wrappers import admin_list_game_binary_records_v1_async
from .wrappers import admin_post_game_binary_presigned_urlv1
from .wrappers import admin_post_game_binary_presigned_urlv1_async
from .wrappers import admin_post_game_binary_record_v1
from .wrappers import admin_post_game_binary_record_v1_async
from .wrappers import admin_put_game_binary_recor_metadata_v1
from .wrappers import admin_put_game_binary_recor_metadata_v1_async
from .wrappers import admin_put_game_binary_record_v1
from .wrappers import admin_put_game_binary_record_v1_async

# admin_game_record
from .wrappers import admin_delete_game_record_handler_v1
from .wrappers import admin_delete_game_record_handler_v1_async
from .wrappers import admin_get_game_record_handler_v1
from .wrappers import admin_get_game_record_handler_v1_async
from .wrappers import admin_post_game_record_handler_v1
from .wrappers import admin_post_game_record_handler_v1_async
from .wrappers import admin_put_game_record_handler_v1
from .wrappers import admin_put_game_record_handler_v1_async
from .wrappers import list_game_records_handler_v1
from .wrappers import list_game_records_handler_v1_async

# admin_player_binary_record
from .wrappers import admin_delete_player_binary_record_v1
from .wrappers import admin_delete_player_binary_record_v1_async
from .wrappers import admin_get_player_binary_record_v1
from .wrappers import admin_get_player_binary_record_v1_async
from .wrappers import admin_list_player_binary_records_v1
from .wrappers import admin_list_player_binary_records_v1_async
from .wrappers import admin_post_player_binary_presigned_urlv1
from .wrappers import admin_post_player_binary_presigned_urlv1_async
from .wrappers import admin_post_player_binary_record_v1
from .wrappers import admin_post_player_binary_record_v1_async
from .wrappers import admin_put_player_binary_recor_metadata_v1
from .wrappers import admin_put_player_binary_recor_metadata_v1_async
from .wrappers import admin_put_player_binary_record_v1
from .wrappers import admin_put_player_binary_record_v1_async

# admin_player_record
from .wrappers import admin_bulk_get_player_records_by_user_i_ds_handler_v1
from .wrappers import admin_bulk_get_player_records_by_user_i_ds_handler_v1_async
from .wrappers import admin_bulk_put_player_records_by_key_handler_v1
from .wrappers import admin_bulk_put_player_records_by_key_handler_v1_async
from .wrappers import admin_delete_player_public_record_handler_v1
from .wrappers import admin_delete_player_public_record_handler_v1_async
from .wrappers import admin_delete_player_record_handler_v1
from .wrappers import admin_delete_player_record_handler_v1_async
from .wrappers import admin_get_player_public_record_handler_v1
from .wrappers import admin_get_player_public_record_handler_v1_async
from .wrappers import admin_get_player_record_handler_v1
from .wrappers import admin_get_player_record_handler_v1_async
from .wrappers import admin_get_player_record_size_handler_v1
from .wrappers import admin_get_player_record_size_handler_v1_async
from .wrappers import admin_get_player_records_handler_v1
from .wrappers import admin_get_player_records_handler_v1_async
from .wrappers import admin_post_player_public_record_handler_v1
from .wrappers import admin_post_player_public_record_handler_v1_async
from .wrappers import admin_post_player_record_handler_v1
from .wrappers import admin_post_player_record_handler_v1_async
from .wrappers import admin_put_player_public_record_handler_v1
from .wrappers import admin_put_player_public_record_handler_v1_async
from .wrappers import admin_put_player_record_handler_v1
from .wrappers import admin_put_player_record_handler_v1_async
from .wrappers import admin_put_player_records_handler_v1
from .wrappers import admin_put_player_records_handler_v1_async
from .wrappers import admin_retrieve_player_records
from .wrappers import admin_retrieve_player_records_async
from .wrappers import bulk_get_player_record_size_handler_v1
from .wrappers import bulk_get_player_record_size_handler_v1_async
from .wrappers import list_player_record_handler_v1
from .wrappers import list_player_record_handler_v1_async

# admin_record
from .wrappers import admin_bulk_get_admin_game_record_v1
from .wrappers import admin_bulk_get_admin_game_record_v1_async
from .wrappers import admin_bulk_get_admin_player_record_v1
from .wrappers import admin_bulk_get_admin_player_record_v1_async
from .wrappers import admin_delete_admin_game_record_v1
from .wrappers import admin_delete_admin_game_record_v1_async
from .wrappers import admin_delete_admin_player_record_v1
from .wrappers import admin_delete_admin_player_record_v1_async
from .wrappers import admin_get_admin_game_record_v1
from .wrappers import admin_get_admin_game_record_v1_async
from .wrappers import admin_get_admin_player_record_v1
from .wrappers import admin_get_admin_player_record_v1_async
from .wrappers import admin_list_admin_game_record_v1
from .wrappers import admin_list_admin_game_record_v1_async
from .wrappers import admin_list_admin_user_records_v1
from .wrappers import admin_list_admin_user_records_v1_async
from .wrappers import admin_post_admin_game_record_v1
from .wrappers import admin_post_admin_game_record_v1_async
from .wrappers import admin_post_player_admin_record_v1
from .wrappers import admin_post_player_admin_record_v1_async
from .wrappers import admin_put_admin_game_record_v1
from .wrappers import admin_put_admin_game_record_v1_async
from .wrappers import admin_put_admin_player_record_v1
from .wrappers import admin_put_admin_player_record_v1_async
from .wrappers import bulk_get_admin_player_record_by_user_ids_v1
from .wrappers import bulk_get_admin_player_record_by_user_ids_v1_async

# admin_tags
from .wrappers import admin_delete_tag_handler_v1
from .wrappers import admin_delete_tag_handler_v1_async
from .wrappers import admin_list_tags_handler_v1
from .wrappers import admin_list_tags_handler_v1_async
from .wrappers import admin_post_tag_handler_v1
from .wrappers import admin_post_tag_handler_v1_async

# concurrent_record
from .wrappers import put_game_record_concurrent_handler_v1
from .wrappers import put_game_record_concurrent_handler_v1_async
from .wrappers import put_player_public_record_concurrent_handler_v1
from .wrappers import put_player_public_record_concurrent_handler_v1_async
from .wrappers import put_player_record_concurrent_handler_v1
from .wrappers import put_player_record_concurrent_handler_v1_async

# plugin_config
from .wrappers import create_plugin_config
from .wrappers import create_plugin_config_async
from .wrappers import delete_plugin_config
from .wrappers import delete_plugin_config_async
from .wrappers import get_plugin_config
from .wrappers import get_plugin_config_async
from .wrappers import update_plugin_config
from .wrappers import update_plugin_config_async

# public_game_binary_record
from .wrappers import bulk_get_game_binary_record_v1
from .wrappers import bulk_get_game_binary_record_v1_async
from .wrappers import delete_game_binary_record_v1
from .wrappers import delete_game_binary_record_v1_async
from .wrappers import get_game_binary_record_v1
from .wrappers import get_game_binary_record_v1_async
from .wrappers import list_game_binary_records_v1
from .wrappers import list_game_binary_records_v1_async
from .wrappers import post_game_binary_presigned_urlv1
from .wrappers import post_game_binary_presigned_urlv1_async
from .wrappers import post_game_binary_record_v1
from .wrappers import post_game_binary_record_v1_async
from .wrappers import put_game_binary_record_v1
from .wrappers import put_game_binary_record_v1_async

# public_game_record
from .wrappers import delete_game_record_handler_v1
from .wrappers import delete_game_record_handler_v1_async
from .wrappers import get_game_record_handler_v1
from .wrappers import get_game_record_handler_v1_async
from .wrappers import get_game_records_bulk
from .wrappers import get_game_records_bulk_async
from .wrappers import post_game_record_handler_v1
from .wrappers import post_game_record_handler_v1_async
from .wrappers import put_game_record_handler_v1
from .wrappers import put_game_record_handler_v1_async

# public_player_binary_record
from .wrappers import bulk_get_my_binary_record_v1
from .wrappers import bulk_get_my_binary_record_v1_async
from .wrappers import bulk_get_other_player_public_binary_records_v1
from .wrappers import bulk_get_other_player_public_binary_records_v1_async
from .wrappers import bulk_get_player_public_binary_records_v1
from .wrappers import bulk_get_player_public_binary_records_v1_async
from .wrappers import delete_player_binary_record_v1
from .wrappers import delete_player_binary_record_v1_async
from .wrappers import get_player_binary_record_v1
from .wrappers import get_player_binary_record_v1_async
from .wrappers import get_player_public_binary_records_v1
from .wrappers import get_player_public_binary_records_v1_async
from .wrappers import list_my_binary_records_v1
from .wrappers import list_my_binary_records_v1_async
from .wrappers import list_other_player_public_binary_records_v1
from .wrappers import list_other_player_public_binary_records_v1_async
from .wrappers import post_player_binary_presigned_urlv1
from .wrappers import post_player_binary_presigned_urlv1_async
from .wrappers import post_player_binary_record_v1
from .wrappers import post_player_binary_record_v1_async
from .wrappers import put_player_binary_recor_metadata_v1
from .wrappers import put_player_binary_recor_metadata_v1_async
from .wrappers import put_player_binary_record_v1
from .wrappers import put_player_binary_record_v1_async

# public_player_record
from .wrappers import bulk_get_player_public_record_handler_v1
from .wrappers import bulk_get_player_public_record_handler_v1_async
from .wrappers import delete_player_record_handler_v1
from .wrappers import delete_player_record_handler_v1_async
from .wrappers import get_other_player_public_record_handler_v1
from .wrappers import get_other_player_public_record_handler_v1_async
from .wrappers import get_other_player_public_record_key_handler_v1
from .wrappers import get_other_player_public_record_key_handler_v1_async
from .wrappers import get_player_public_record_handler_v1
from .wrappers import get_player_public_record_handler_v1_async
from .wrappers import get_player_record_handler_v1
from .wrappers import get_player_record_handler_v1_async
from .wrappers import get_player_records_bulk_handler_v1
from .wrappers import get_player_records_bulk_handler_v1_async
from .wrappers import post_player_public_record_handler_v1
from .wrappers import post_player_public_record_handler_v1_async
from .wrappers import post_player_record_handler_v1
from .wrappers import post_player_record_handler_v1_async
from .wrappers import public_delete_player_public_record_handler_v1
from .wrappers import public_delete_player_public_record_handler_v1_async
from .wrappers import put_player_public_record_handler_v1
from .wrappers import put_player_public_record_handler_v1_async
from .wrappers import put_player_record_handler_v1
from .wrappers import put_player_record_handler_v1_async
from .wrappers import retrieve_player_records
from .wrappers import retrieve_player_records_async

# public_tags
from .wrappers import public_list_tags_handler_v1
from .wrappers import public_list_tags_handler_v1_async

# ttl_config
from .wrappers import delete_game_binary_record_ttl_config
from .wrappers import delete_game_binary_record_ttl_config_async
from .wrappers import delete_game_record_ttl_config
from .wrappers import delete_game_record_ttl_config_async
