# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Legal Service."""

__version__ = "1.44.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .retrieve_country_list_w_8c69ff import RetrieveCountryListWithPolicies
from .retrieve_latest_policies import RetrieveLatestPolicies
from .retrieve_latest_policies import (
    PolicyTypeEnum as RetrieveLatestPoliciesPolicyTypeEnum,
)
from .retrieve_latest_policie_95ffb6 import (
    RetrieveLatestPoliciesByNamespaceAndCountryPublic,
)
from .retrieve_latest_policie_95ffb6 import (
    PolicyTypeEnum as RetrieveLatestPoliciesByNamespaceAndCountryPublicPolicyTypeEnum,
)
from .retrieve_latest_policie_29f65f import RetrieveLatestPoliciesPublic
from .retrieve_latest_policie_29f65f import (
    PolicyTypeEnum as RetrieveLatestPoliciesPublicPolicyTypeEnum,
)
from .retrieve_policies import RetrievePolicies
from .set_default_policy_2 import SetDefaultPolicy2
from .update_policy import UpdatePolicy
