# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Cloudsave Service."""

__version__ = "3.21.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_bulk_get_admin_ga_c5c529 import AdminBulkGetAdminGameRecordV1
from .admin_bulk_get_admin_pl_b8e62a import AdminBulkGetAdminPlayerRecordV1
from .admin_delete_admin_game_1f080f import AdminDeleteAdminGameRecordV1
from .admin_delete_admin_play_632fe7 import AdminDeleteAdminPlayerRecordV1
from .admin_get_admin_game_record_v1 import AdminGetAdminGameRecordV1
from .admin_get_admin_player__37ad38 import AdminGetAdminPlayerRecordV1
from .admin_list_admin_game_r_476bfb import AdminListAdminGameRecordV1
from .admin_list_admin_user_r_83dd7a import AdminListAdminUserRecordsV1
from .admin_post_admin_game_r_e8f678 import AdminPostAdminGameRecordV1
from .admin_post_player_admin_b138ee import AdminPostPlayerAdminRecordV1
from .admin_put_admin_game_record_v1 import AdminPutAdminGameRecordV1
from .admin_put_admin_player__6ed45f import AdminPutAdminPlayerRecordV1
from .bulk_get_admin_player_r_e53570 import BulkGetAdminPlayerRecordByUserIdsV1
