# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Ds Artifact Manager."""

__version__ = "1.11.5"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .delete_active_queue import DeleteActiveQueue
from .delete_node_by_id import DeleteNodeByID
from .delete_queue import DeleteQueue
from .get_active_queue import GetActiveQueue
from .list_all_active_queue import ListAllActiveQueue
from .list_all_queue import ListAllQueue
from .list_nodes_ip_address import ListNodesIPAddress
from .list_queue import ListQueue
from .report_failed_upload import ReportFailedUpload
from .set_active_queue import SetActiveQueue
