# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Iam Service."""

__version__ = "7.21.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_change_role_overr_28b2d2 import AdminChangeRoleOverrideConfigStatusV3
from .admin_change_role_overr_28b2d2 import (
    IdentityEnum as AdminChangeRoleOverrideConfigStatusV3IdentityEnum,
)
from .admin_get_role_namespac_f41126 import AdminGetRoleNamespacePermissionV3
from .admin_get_role_override_a15e07 import AdminGetRoleOverrideConfigV3
from .admin_get_role_override_a15e07 import (
    IdentityEnum as AdminGetRoleOverrideConfigV3IdentityEnum,
)
from .admin_get_role_source_v3 import AdminGetRoleSourceV3
from .admin_get_role_source_v3 import IdentityEnum as AdminGetRoleSourceV3IdentityEnum
from .admin_update_role_overr_6f2e5d import AdminUpdateRoleOverrideConfigV3
from .admin_update_role_overr_6f2e5d import (
    IdentityEnum as AdminUpdateRoleOverrideConfigV3IdentityEnum,
)
