# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Service."""

__version__ = "3.17.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_delete_bulk_game__144132 import AdminDeleteBulkGameSessions
from .admin_kick_game_session_member import AdminKickGameSessionMember
from .admin_query_game_sessions import AdminQueryGameSessions
from .admin_query_game_sessio_9fd853 import AdminQueryGameSessionsByAttributes
from .admin_set_ds_ready import AdminSetDSReady
from .admin_update_game_sessi_718745 import AdminUpdateGameSessionMember
from .append_team_game_session import AppendTeamGameSession
from .create_game_session import CreateGameSession
from .delete_game_session import DeleteGameSession
from .game_session_generate_code import GameSessionGenerateCode
from .get_game_session import GetGameSession
from .get_game_session_by_pod_name import GetGameSessionByPodName
from .get_session_server_secret import GetSessionServerSecret
from .join_game_session import JoinGameSession
from .leave_game_session import LeaveGameSession
from .patch_update_game_session import PatchUpdateGameSession
from .public_game_session_cancel import PublicGameSessionCancel
from .public_game_session_invite import PublicGameSessionInvite
from .public_game_session_reject import PublicGameSessionReject
from .public_kick_game_sessio_89864f import PublicKickGameSessionMember
from .public_promote_game_ses_482ff3 import PublicPromoteGameSessionLeader
from .public_query_game_sessi_875927 import PublicQueryGameSessionsByAttributes
from .public_query_my_game_sessions import PublicQueryMyGameSessions
from .public_revoke_game_sess_c2a52e import PublicRevokeGameSessionCode
from .public_session_join_code import PublicSessionJoinCode
from .update_game_session import UpdateGameSession
from .update_game_session_bac_df8b84 import UpdateGameSessionBackfillTicketID
