# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Lobby Server."""

__version__ = "3.36.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_bulk_block_players_v1 import AdminBulkBlockPlayersV1
from .admin_bulk_unblock_players_v1 import AdminBulkUnblockPlayersV1
from .admin_get_all_player_se_b925d7 import AdminGetAllPlayerSessionAttribute
from .admin_get_bulk_player_b_0addc5 import AdminGetBulkPlayerBlockedPlayersV1
from .admin_get_lobby_ccu import AdminGetLobbyCCU
from .admin_get_player_blocke_8955db import AdminGetPlayerBlockedByPlayersV1
from .admin_get_player_blocke_7da3f3 import AdminGetPlayerBlockedPlayersV1
from .admin_get_player_sessio_625ce8 import AdminGetPlayerSessionAttribute
from .admin_set_player_sessio_1bc722 import AdminSetPlayerSessionAttribute
from .public_get_player_block_0dc6b7 import PublicGetPlayerBlockedByPlayersV1
from .public_get_player_block_55d58a import PublicGetPlayerBlockedPlayersV1
from .public_player_block_players_v1 import PublicPlayerBlockPlayersV1
from .public_unblock_player_v1 import PublicUnblockPlayerV1
