# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Gdpr Service."""

__version__ = "2.13.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_delete_platform_a_6b01ab import AdminDeletePlatformAccountClosureClient
from .admin_get_platform_acco_4a3f07 import AdminGetPlatformAccountClosureClient
from .admin_update_platform_a_818a23 import AdminUpdatePlatformAccountClosureClient
