# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Browser Service."""

__version__ = "1.18.8"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .add_player_to_session import AddPlayerToSession
from .admin_delete_session import AdminDeleteSession
from .admin_get_session import AdminGetSession
from .admin_query_session import AdminQuerySession
from .admin_search_sessions_v2 import AdminSearchSessionsV2
from .create_session import CreateSession
from .delete_session import DeleteSession
from .delete_session_local_ds import DeleteSessionLocalDS
from .get_active_custom_game__cd6755 import GetActiveCustomGameSessions
from .get_active_matchmaking__0b8050 import GetActiveMatchmakingGameSessions
from .get_recent_player import GetRecentPlayer
from .get_session import GetSession
from .get_session_by_user_i_ds import GetSessionByUserIDs
from .get_session_history_detailed import GetSessionHistoryDetailed
from .get_total_active_session import GetTotalActiveSession
from .join_session import JoinSession
from .remove_player_from_session import RemovePlayerFromSession
from .update_session import UpdateSession
from .update_settings import UpdateSettings
from .user_query_session import UserQuerySession
