# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Event Log Service."""

__version__ = "2.2.5"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .get_event_by_event_id_handler import GetEventByEventIDHandler
from .get_event_by_event_type_8d579c import GetEventByEventTypeAndEventIDHandler
from .get_event_by_event_type_f075bc import GetEventByEventTypeHandler
from .get_event_by_namespace_handler import GetEventByNamespaceHandler
from .get_event_by_user_event_af55e0 import GetEventByUserEventIDAndEventTypeHandler
from .get_event_by_user_id_an_30e3ad import GetEventByUserIDAndEventIDHandler
from .get_event_by_user_id_an_c0de1a import GetEventByUserIDAndEventTypeHandler
from .get_event_by_user_id_handler import GetEventByUserIDHandler
from .post_event_handler import PostEventHandler
