# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Gdpr Service."""

__version__ = "2.13.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._configuration import admin_get_platform_account_closure_services_configuration
from ._configuration import (
    admin_get_platform_account_closure_services_configuration_async,
)
from ._configuration import admin_get_services_configuration
from ._configuration import admin_get_services_configuration_async
from ._configuration import admin_reset_platform_account_closure_services_configuration
from ._configuration import (
    admin_reset_platform_account_closure_services_configuration_async,
)
from ._configuration import admin_reset_services_configuration
from ._configuration import admin_reset_services_configuration_async
from ._configuration import admin_update_platform_account_closure_services_configuration
from ._configuration import (
    admin_update_platform_account_closure_services_configuration_async,
)
from ._configuration import admin_update_services_configuration
from ._configuration import admin_update_services_configuration_async
from ._configuration import delete_admin_email_configuration
from ._configuration import delete_admin_email_configuration_async
from ._configuration import get_admin_email_configuration
from ._configuration import get_admin_email_configuration_async
from ._configuration import save_admin_email_configuration
from ._configuration import save_admin_email_configuration_async
from ._configuration import update_admin_email_configuration
from ._configuration import update_admin_email_configuration_async

from ._data_deletion import admin_cancel_user_account_deletion_request
from ._data_deletion import admin_cancel_user_account_deletion_request_async
from ._data_deletion import admin_get_list_deletion_data_request
from ._data_deletion import admin_get_list_deletion_data_request_async
from ._data_deletion import admin_get_user_account_deletion_request
from ._data_deletion import admin_get_user_account_deletion_request_async
from ._data_deletion import admin_submit_user_account_deletion_request
from ._data_deletion import admin_submit_user_account_deletion_request_async
from ._data_deletion import public_cancel_my_account_deletion_request
from ._data_deletion import public_cancel_my_account_deletion_request_async
from ._data_deletion import public_cancel_user_account_deletion_request
from ._data_deletion import public_cancel_user_account_deletion_request_async
from ._data_deletion import public_get_my_account_deletion_status
from ._data_deletion import public_get_my_account_deletion_status_async
from ._data_deletion import public_get_user_account_deletion_status
from ._data_deletion import public_get_user_account_deletion_status_async
from ._data_deletion import public_submit_my_account_deletion_request
from ._data_deletion import public_submit_my_account_deletion_request_async
from ._data_deletion import public_submit_user_account_deletion_request
from ._data_deletion import public_submit_user_account_deletion_request_async

from ._data_deletion_s2s import s2s_get_list_finished_account_deletion_request
from ._data_deletion_s2s import s2s_get_list_finished_account_deletion_request_async
from ._data_deletion_s2s import s2s_submit_user_account_deletion_request
from ._data_deletion_s2s import s2s_submit_user_account_deletion_request_async

from ._data_retrieval import admin_cancel_user_personal_data_request
from ._data_retrieval import admin_cancel_user_personal_data_request_async
from ._data_retrieval import admin_generate_personal_data_url
from ._data_retrieval import admin_generate_personal_data_url_async
from ._data_retrieval import admin_get_list_personal_data_request
from ._data_retrieval import admin_get_list_personal_data_request_async
from ._data_retrieval import admin_get_user_personal_data_requests
from ._data_retrieval import admin_get_user_personal_data_requests_async
from ._data_retrieval import admin_request_data_retrieval
from ._data_retrieval import admin_request_data_retrieval_async
from ._data_retrieval import public_cancel_user_personal_data_request
from ._data_retrieval import public_cancel_user_personal_data_request_async
from ._data_retrieval import public_generate_personal_data_url
from ._data_retrieval import public_generate_personal_data_url_async
from ._data_retrieval import public_get_user_personal_data_requests
from ._data_retrieval import public_get_user_personal_data_requests_async
from ._data_retrieval import public_request_data_retrieval
from ._data_retrieval import public_request_data_retrieval_async

from ._data_retrieval_s2s import s2s_generate_personal_data_url
from ._data_retrieval_s2s import s2s_generate_personal_data_url_async
from ._data_retrieval_s2s import s2s_get_list_finished_personal_data_request
from ._data_retrieval_s2s import s2s_get_list_finished_personal_data_request_async
from ._data_retrieval_s2s import s2s_request_data_retrieval
from ._data_retrieval_s2s import s2s_request_data_retrieval_async

from ._platform_account_closure_client import (
    admin_delete_platform_account_closure_client,
)
from ._platform_account_closure_client import (
    admin_delete_platform_account_closure_client_async,
)
from ._platform_account_closure_client import admin_get_platform_account_closure_client
from ._platform_account_closure_client import (
    admin_get_platform_account_closure_client_async,
)
from ._platform_account_closure_client import (
    admin_update_platform_account_closure_client,
)
from ._platform_account_closure_client import (
    admin_update_platform_account_closure_client_async,
)

from ._platform_account_closure_history import (
    admin_get_user_platform_account_closure_histories,
)
from ._platform_account_closure_history import (
    admin_get_user_platform_account_closure_histories_async,
)
